<?php

namespace B2buy\Customprice\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Customprice\Http\Requests\CustompriceRequest;
use B2buy\Customprice\Interfaces\CustompriceRepositoryInterface;
use B2buy\Customprice\Models\Customprice;
use B2buy\Customprice\Forms\Customprice as Form;

/**
 * APIController  class for customprice.
 */
class CustompriceAPIController extends BaseController
{

    /**
     * Initialize customprice resource controller.
     *
     * @param type CustompriceRepositoryInterface $customprice
     *
     * @return null
     */
    public function __construct(CustompriceRepositoryInterface $customprice)
    {
        parent::__construct();
        $this->repository = $customprice;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Customprice\Repositories\Criteria\CustompriceResourceCriteria::class);
    }

    /**
     * Display a list of customprice.
     *
     * @return Response
     */
    public function index(CustompriceRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Customprice\Repositories\Presenter\CustompricePresenter::class)
            ->paginate();
    }

    /**
     * Display customprice.
     *
     * @param Request $request
     * @param Model   $customprice
     *
     * @return Response
     */
    public function show(CustompriceRequest $request, Customprice $customprice)
    {
        return $customprice->setPresenter(\B2buy\Customprice\Repositories\Presenter\CustompriceListPresenter::class);
        ;
    }

    /**
     * Create new customprice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CustompriceRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('customprice::customprice.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('customprice/customprice/' . $customprice->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('customprice/customprice');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the customprice.
     *
     * @param Request $request
     * @param Model   $customprice
     *
     * @return Response
     */
    public function update(CustompriceRequest $request, Customprice $customprice)
    {
        try {
            $data = $request->all();

            $customprice->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('customprice::customprice.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('customprice/customprice/' . $customprice->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('customprice/customprice/' . $customprice->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the customprice.
     *
     * @param Model   $customprice
     *
     * @return Response
     */
    public function destroy(CustompriceRequest $request, Customprice $customprice)
    {
        try {
            $customprice->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('customprice::customprice.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('customprice/customprice/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('customprice/customprice/' . $customprice->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
