<?php

namespace B2buy\Customprice\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Customprice\Models\Customprice;

class CustompricePolicy
{

    /**
     * Determine if the given user can view the customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Customprice $customprice)
    {
        if ($user->canDo('customprice.customprice.view') && $user->isAdmin()) {
            return true;
        }

        return $customprice->user_id == user_id() && $customprice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('customprice.customprice.create');
    }

    /**
     * Determine if the given user can update the given customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Customprice $customprice)
    {
        if ($user->canDo('customprice.customprice.edit') && $user->isAdmin()) {
            return true;
        }

        return $customprice->user_id == user_id() && $customprice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Customprice $customprice)
    {
        return $customprice->user_id == user_id() && $customprice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Customprice $customprice)
    {
        if ($user->canDo('customprice.customprice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given customprice.
     *
     * @param UserPolicy $user
     * @param Customprice $customprice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Customprice $customprice)
    {
        if ($user->canDo('customprice.customprice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
